@@ -18,7 +18,7 @@ class StreamHandler(object):
 
     def _handle_reply(self, msg):
         self.stream.close()
-        self.callback(self.client._get_validate_payload(self.service, msg))
+        self.callback(self.client._get_validate_payload(msg))
 
 
 def send(service, request, callback):
